@@ -3,7 +3,7 @@
 //
 //  Email:                     individual61@users.sourceforge.net
 //
-//  Version:                   0.5.2   (10 / I / 2005)
+//  Version:                   0.5.3   (24 / I / 2005)
 //
 //  Description:               Library that allows plotting a 48 bit
 //                             PNG image pixel by pixel, which can 
@@ -43,7 +43,7 @@
 #ifndef PNGWRITER_H
 #define PNGWRITER_H 1
 
-#define PNGWRITER_VERSION 0.52
+#define PNGWRITER_VERSION 0.53
 
 #include <png.h>
 
@@ -663,6 +663,71 @@ class pngwriter
     * */
    void filledtriangle_blend(int x1,int y1,int x2,int y2,int x3,int y3, double opacity, int red, int green, int blue);
    void filledtriangle_blend(int x1,int y1,int x2,int y2,int x3,int y3, double opacity, double red, double green, double blue);
+
+   /* Arrow,  Filled Arrow
+    * Plots an arrow from (x1, y1) to (x2, y2) with the arrowhead at the second point, given the size in pixels
+    * and the angle in radians of the arrowhead. The plotted arrow consists of one main line, and two smaller 
+    * lines originating from the second point. Filled Arrow plots the same, but the arrowhead is a solid triangle.
+    * Tip: An angle of 10 to 30 degrees looks OK.
+    * */
+   
+   void arrow( int x1,int y1,int x2,int y2,int size, double head_angle, double red, double green, double blue);
+   void arrow( int x1,int y1,int x2,int y2,int size, double head_angle, int red, int green, int blue);
+   
+   void filledarrow( int x1,int y1,int x2,int y2,int size, double head_angle, double red, double green, double blue);
+   void filledarrow( int x1,int y1,int x2,int y2,int size, double head_angle, int red, int green, int blue);
+
+   /* Cross, Maltese Cross
+    * Plots a simple cross at x, y, with the specified height and width, and in the specified colour.
+    * Maltese cross plots a cross, as before, but adds bars at the end of each arm of the cross.
+    * The size of these bars is specified with x_bar_height and y_bar_width.
+    * The cross will look something like this:
+    * 
+    *    -----  <-- ( y_bar_width)
+    *      |
+    *      |
+    *  |-------|  <-- ( x_bar_height )
+    *      |
+    *      |
+    *    -----
+    * */
+   
+   void cross( int x, int y, int xwidth, int yheight, double red, double green, double blue);
+   void cross( int x, int y, int xwidth, int yheight, int red, int green, int blue);
+
+   void maltesecross( int x, int y, int xwidth, int yheight, int x_bar_height, int y_bar_width, double red, double green, double blue);
+   void maltesecross( int x, int y, int xwidth, int yheight, int x_bar_height, int y_bar_width, int red, int green, int blue);
+
+   /* Diamond and filled diamond
+    * Plots a diamond shape, given the x, y position, the width and height, and the colour.
+    * Filled diamond plots a filled diamond.
+    * */
+   
+   void filleddiamond( int x, int y, int width, int height, int red, int green, int blue);
+   void diamond(int x, int y, int width, int height, int red, int green, int blue);
+   
+   void filleddiamond( int x, int y, int width, int height, double red, double green, double blue);
+   void diamond(int x, int y, int width, int height, double red, double green, double blue);
+
+   /* Get Text Width, Get Text Width UTF8
+    * Returns the approximate width, in pixels, of the specified *unrotated* text. It is calculated by adding 
+    * each letter's width and kerning value (as specified in the TTF file). Note that this will not 
+    * give the position of the farthest pixel, but it will give a pretty good idea of what area the 
+    * text will occupy. Tip: The text, when plotted unrotated, will fit approximately in a box with its lower left corner at 
+    * (x_start, y_start) and upper right at (x_start + width, y_start + size), where width is given by get_text_width()
+    * and size is the specified size of the text to be plotted. Tip: Text plotted at position
+    * (x_start, y_start), rotated with a given 'angle', and of a given 'size'
+    * whose width is 'width', will fit approximately inside a rectangle whose corners are at
+    *     1  (x_start, y_start)
+    *     2  (x_start + width*cos(angle), y_start + width*sin(angle))
+    *     3  (x_start + width*cos(angle) - size*sin(angle), y_start + width*sin(angle) + size*cos(angle))
+    *     4  (x_start - size*sin(angle), y_start + size*cos(angle))  
+    * */
+   
+   int get_text_width(char * face_path, int fontsize,  char * text);
+
+   int get_text_width_utf8(char * face_path, int fontsize, char * text);
+   
    
 };
 
